aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorUlrich Müller <ulm@gentoo.org>2015-10-11 00:17:15 +0200
committerUlrich Müller <ulm@gentoo.org>2015-10-11 00:17:15 +0200
commitc77e06ffac4dcc221b9cf8b6219d945ec0ae6ffa (patch)
treece1355e1ec3c51f259b8954dcfc15f9455c21fa9 /find-binary-files.sh
parentfetch-git-reports: Fetch all branches (diff)
downloadqa-scripts-c77e06ffac4dcc221b9cf8b6219d945ec0ae6ffa.tar.gz
qa-scripts-c77e06ffac4dcc221b9cf8b6219d945ec0ae6ffa.tar.bz2
qa-scripts-c77e06ffac4dcc221b9cf8b6219d945ec0ae6ffa.zip
find-binary-files.sh: More false positives for GNU Info files.
Diffstat (limited to 'find-binary-files.sh')
-rwxr-xr-xfind-binary-files.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/find-binary-files.sh b/find-binary-files.sh
index ccff2d6..98346de 100755
--- a/find-binary-files.sh
+++ b/find-binary-files.sh
@@ -1,5 +1,5 @@
#!/bin/bash
-# Copyright 2014 Gentoo Foundation
+# Copyright 2014-2015 Gentoo Foundation
# Distributed under the terms of the GNU GPL version 2 or later
# Author: Ulrich Müller <ulm@gentoo.org>
@@ -21,9 +21,10 @@ find . \( -path ./distfiles -o -path ./local -o -path ./metadata \
# GNU Info files (or patches to them) can contain the following
# control characters that produce false positives:
# - 0x1f, followed by LF or FF
# - 0x7f (DEL), preceded by "Node:" in the same line
# Filter such characters and reiterate
- line=$(sed -e 's/\x1f\f\?$//;/Node:/s/\x7f//' "${path}" | file -i -)
+ line=$(sed -e 's/\x1f\f\?$//;/\(Node\|Ref\):/s/\x7f//' "${path}" \
+ | file -i -)
type=${line##*:*( )}
;;
esac
@@ -21,9 +21,10 @@ find . \( -path ./distfiles -o -path ./local -o -path ./metadata \
# control characters that produce false positives:
# - 0x1f, followed by LF or FF
- # - 0x7f (DEL), preceded by "Node:" in the same line
+ # - 0x7f (DEL), preceded by "Node:" or "Ref:" in the same line
# Filter such characters and reiterate